graphium.nn.encoders
====================

Implementations of positional encoders in the library

=== "Contents"

    * [Base Encoder](#base-encoder)
    * [Gaussian Kernal Positional Encoder](#gaussian-kernal-positional-encoder)
    * [Laplacian Positional Encoder](#laplacian-positional-encoder)
    * [MLP Encoder](#mlp-encoder)
    * [Signnet Positional Encoder](#signnet-positional-encoder)


## Base Encoder
------------
::: graphium.nn.encoders.base_encoder


## Gaussian Kernal Positional Encoder
------------
::: graphium.nn.encoders.gaussian_kernel_pos_encoder


## Laplacian Positional Encoder
------------
::: graphium.nn.encoders.laplace_pos_encoder


## MLP Encoder
------------
::: graphium.nn.encoders.mlp_encoder


## Signnet Positional Encoder
------------
::: graphium.nn.encoders.signnet_pos_encoder
